package cd.casic.ci.common.pipeline.pojo.agent;

import cd.casic.ci.common.pipeline.type.BuildType;
import cd.casic.ci.common.pipeline.utils.EnvUtils;
import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Getter;
import lombok.Setter;

import java.util.Map;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.type.agent
 * @Project：ops-pro
 * @name：ThirdPartyAgentEnvDispatchType
 * @Date：2025/03/27 10:48
 * @Filename：ThirdPartyAgentEnvDispatchType
 * @description：Todo
 */
@Getter
@Setter
public class ThirdPartyAgentEnvDispatchType extends ThirdPartyAgentDispatch {
    @JsonProperty("value")
    private String envName;
    private String workspace;
    private String envProjectId;
    private AgentType agentType = AgentType.NAME;
    private ThirdPartyAgentDockerInfo dockerInfo;
    private ReusedInfo reusedInfo;

    public ThirdPartyAgentEnvDispatchType(String envName, String workspace, String envProjectId, ThirdPartyAgentDockerInfo dockerInfo, ReusedInfo reusedInfo) {
        super(envName, AgentType.NAME, workspace, dockerInfo, reusedInfo);
        this.envName = envName;
        this.workspace = workspace;
        this.envProjectId = envProjectId;
        this.dockerInfo = dockerInfo;
        this.reusedInfo = reusedInfo;
    }

    @Override
    public void cleanDataBeforeSave() {
        this.envName = this.envName.trim();
        this.envProjectId = this.envProjectId != null ? this.envProjectId.trim() : null;
        this.workspace = this.workspace != null ? this.workspace.trim() : null;
    }

    @Override
    public void replaceField(Map<String, String> variables) {
        envName = EnvUtils.parseEnv(envName, variables);
        envProjectId = EnvUtils.parseEnv(envProjectId, variables);
        if (workspace != null && !workspace.isBlank()) {
            workspace = EnvUtils.parseEnv(workspace, variables);
        }
        if (dockerInfo != null) {
            dockerInfo.replaceField(variables);
        }
    }

    @Override
    public BuildType buildType() {
        return BuildType.THIRD_PARTY_AGENT_ENV;
    }
}
