package cd.casic.ci.log.api;



import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.ci.log.dal.pojo.enums.LogStorageMode;
import cd.casic.ci.log.dal.pojo.message.LogMessage;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_DEVOPS_BUILD_ID;


@RestController
@Tag(name = "服务-日志打印资源")
@RequestMapping("/service/logs/print")
public interface ServiceLogPrintResource {

    @Operation(summary = "写入日志状态")
    @PostMapping("/status")
    @Parameters({
            @Parameter(name = "tag", description = "分辨插件的tag，默认填对应插件id"),
            @Parameter(name = "subTag", description = "插件内的分类的子tag，默认为空"),
            @Parameter(name = "jobId", description = "job id或者container的34位id"),
            @Parameter(name = "executeCount", description = "执行次数"),

    })
    CommonResult<Boolean> addLogStatus(@RequestHeader(value = AUTH_HEADER_DEVOPS_BUILD_ID)
                                       @Parameter(description = "构建ID", required = true)
                                               String buildId,
                                       @RequestParam(value = "tag", required = false) String tag,
                                       @RequestParam(value = "subTag", required = false) String subTag,
                                       @RequestParam(value = "jobId", required = false) String jobId,
                                       @RequestParam(value = "executeCount", required = false, defaultValue = "1") int executeCount);

    @Operation(summary = "更新日志状态")
    @PutMapping("/status")
    CommonResult<Boolean> updateLogStatus(
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID)
                    String buildId,
            @Parameter(description = "是否已构建完成", required = true)
            @RequestParam("finished")
                    boolean finished,
            @Parameter(description = "分辨插件的tag，默认填对应插件id")
            @RequestParam(value = "tag", required = false)
                    String tag,
            @Parameter(description = "插件内的分类的子tag，默认为空")
            @RequestParam(value = "subTag", required = false)
                    String subTag,
            @Parameter(description = "job id或者container的34位id")
            @RequestParam(value = "jobId", required = false)
                    String jobId,
            @Parameter(description = "执行次数")
            @RequestParam(value = "executeCount", required = false, defaultValue = "1")
                    int executeCount,
            @Parameter(description = "插件的存储模式")
            @RequestParam(value = "logStorageMode", required = false)
            LogStorageMode logStorageMode
    );

    @Operation(summary = "写入一条日志")
    @PostMapping("/")
    CommonResult<Boolean> addLogLine(
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID)
                    String buildId,
            @Parameter(description = "一条日志", required = true)
            LogMessage logMessage);

    @Operation(summary = "写入多条日志")
    @PostMapping("/multi")
    CommonResult<Boolean> addLogMultiLine(
            @Parameter(description = "构建ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_BUILD_ID)
                    String buildId,

            @Parameter(description = "多条日志列表", required = true)
            List<LogMessage> logMessages);

}
