package cd.casic.ci.process.command;

/**
 * @author by mianbin
 * @Classname Cmd
 * @Description 定义引擎命令
 * @Date 2025/4/7 19:37
 */
public interface Cmd<T extends CmdContext> {
    /**
     * 当前[commandContext]上下文能否满足运行条件
     *
     * @param commandContext 命令上下文
     * @return 如果满足运行条件返回 true，否则返回 false
     */
    boolean canExecute(T commandContext);

    /**
     * 本命令[commandContext]上下文执行核心处理逻辑
     *
     * @param commandContext 命令上下文
     */
    void execute(T commandContext);

    /**
     * 执行总入口，将调用[canExecute]判断是否满足再执行[execute]函数，
     * 并将[chain]链式传递[commandContext]继续执行下去
     *
     * @param commandContext 命令上下文
     * @param chain 命令链
     */
    default void doExecute(T commandContext, CmdChain<T> chain) {
        if (canExecute(commandContext)) {
            execute(commandContext);
        }
        chain.doCommand(commandContext);
    }
}
