package cd.casic.ci.process.command;

/**
 * @author by mianbin
 * @Classname CmdChain
 * @Description 引擎控制命令链
 * @Date 2025/4/7 19:37
 */
public interface CmdChain<T extends CmdContext> {

    /**
     * 使用泛型的命令上下文[commandContext]执行命令
     * [commandContext]具备传递和存储中间数据，由各部件定义
     *
     * @param commandContext 命令上下文
     */
    default void doCommand(T commandContext) {
        if (commandContext.getCmdFlowSeq() < 0) { // 校正
            commandContext.setCmdFlowSeq(0);
        }
        // 每次调用，都增1，走向下一条命令链
        Cmd<T> nextCmd = nextCommand(commandContext);
        if (nextCmd != null) {
            nextCmd.doExecute(commandContext, this);
        }
    }

    /**
     * 获取下一个命令
     *
     * @param commandContext 命令上下文
     * @return 下一个命令，如果没有则返回 null
     */
    Cmd<T> nextCommand(T commandContext);
}
