package cd.casic.pipeline.store.api.common;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.common.platform.StoreDockingPlatformRequest;
import cd.casic.pipeline.store.pojo.common.publication.PublishersRequest;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.*;

@Tag(name = "BUILD_PUBLISHER", description = "build_publisher")
@RestController
@RequestMapping("/build/store/publisher/sync")
public interface BuildPublishersResource {

    @Operation(summary = "同步新增发布者信息")
    @PostMapping("/add")
    CommonResult<Integer> synAddPublisherData(
            @RequestHeader(AUTH_HEADER_DEVOPS_USER_ID)
            @Parameter(description = "用户ID", required = true)
            String userId,
            @Parameter(description = "发布者数据同步请求", required = true)
            List<PublishersRequest> publishers
    );

    @Operation(summary = "同步删除发布者信息")
    @DeleteMapping("/delete")
    CommonResult<Integer> synDeletePublisherData(
            @RequestHeader(AUTH_HEADER_DEVOPS_USER_ID)
            @Parameter(description = "用户ID", required = true)
            String userId,
            @Parameter(description = "发布者数据同步请求", required = true)
            List<PublishersRequest> publishers
    );

    @Operation(summary = "同步更新发布者信息")
    @PostMapping("/update")
    CommonResult<Integer> synUpdatePublisherData(
            @RequestHeader(AUTH_HEADER_DEVOPS_USER_ID)
            @Parameter(description = "用户ID", required = true)
            String userId,
            @Parameter(description = "发布者数据同步请求", required = true)
            List<PublishersRequest> publishers
    );

    @Operation(summary = "同步新增工具平台信息")
    @PostMapping("/platforms/add")
    CommonResult<Integer> synAddPlatformsData(
            @RequestHeader(AUTH_HEADER_DEVOPS_USER_ID)
            @Parameter(description = "用户ID", required = true)
            String userId,
            @Parameter(description = "store组件对接平台请求", required = true)
            List<StoreDockingPlatformRequest> storeDockingPlatformRequests
    );

    @Operation(summary = "同步删除工具平台信息")
    @DeleteMapping("/platforms/delete")
    CommonResult<Integer> synDeletePlatformsData(
            @RequestHeader(AUTH_HEADER_DEVOPS_USER_ID)
            @Parameter(description = "用户ID", required = true)
            String userId,
            @Parameter(description = "store组件对接平台请求", required = true)
            List<StoreDockingPlatformRequest> storeDockingPlatformRequests
    );

    @Operation(summary = "同步更新工具平台信息")
    @PostMapping("/platforms/update")
    CommonResult<Integer> synUpdatePlatformsData(
            @RequestHeader(AUTH_HEADER_DEVOPS_USER_ID)
            @Parameter(description = "用户ID", required = true)
            String userId,
            @Parameter(description = "store组件对接平台请求", required = true)
            List<StoreDockingPlatformRequest> storeDockingPlatformRequests
    );

    @Operation(summary = "同步更新工具平台logo信息")
    @PostMapping("/platforms/logo/update")
    CommonResult<Boolean> synUpdatePlatformsLogoInfo(
            @RequestHeader(AUTH_HEADER_DEVOPS_USER_ID)
            @Parameter(description = "用户ID", required = true)
            String userId,
            @Parameter(description = "平台代码", required = true)
            @RequestParam("platformCode")
            String platformCode,
            @Parameter(description = "logoUrl", required = true)
            @RequestParam("logoUrl")
            String logoUrl
    );
}