package cd.casic.pipeline.store.api.common;


import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.common.StoreOfflineRequest;
import cd.casic.pipeline.store.pojo.common.StoreReleaseInfoUpdateRequest;
import cd.casic.pipeline.store.pojo.common.publication.*;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;

@Tag(name = "USER_STORE_RELEASE", description = "研发商店-发布管理")
@RestController
@RequestMapping("/user/store/releases")
public interface UserStoreReleaseResource {

    @Operation(summary = "新增组件")
    @PostMapping("/component/create")
    CommonResult<StoreCreateResponse> createComponent(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "工作台-新增组件请求报文体", required = true)
            @Valid
            StoreCreateRequest storeCreateRequest
    );

    @Operation(summary = "更新组件")
    @PutMapping("/component/update")
    CommonResult<StoreUpdateResponse> updateComponent(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "工作台-更新组件请求报文体", required = true)
            @Valid
            StoreUpdateRequest storeUpdateRequest
    );

    @Operation(summary = "根据组件ID获取版本发布进度")
    @GetMapping("/components/{storeId}/process/info")
    CommonResult<StoreProcessInfo> getProcessInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "storeId", required = true)
            @PathVariable("storeId")
            String storeId
    );

    @Operation(summary = "取消版本发布")
    @PutMapping("/components/{storeId}/cancel")
    CommonResult<Boolean> cancelRelease(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "storeId", required = true)
            @PathVariable("storeId")
            String storeId
    );

    @Operation(summary = "确认通过测试")
    @PutMapping("/components/{storeId}/test/pass")
    CommonResult<Boolean> passTest(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "storeId", required = true)
            @PathVariable("storeId")
            String storeId
    );

    @Operation(summary = "填写信息")
    @PutMapping("/components/{storeId}/release/info/edit")
    CommonResult<Boolean> editReleaseInfo(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "storeId", required = true)
            @PathVariable("storeId")
            String storeId,
            @Parameter(description = "填写信息请求报文体", required = true)
            @Valid
            StoreReleaseInfoUpdateRequest storeReleaseInfoUpdateRequest
    );

    @Operation(summary = "下架组件")
    @PutMapping("/component/offline")
    CommonResult<Boolean> offlineComponent(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "工作台-下架组件请求报文体", required = true)
            @Valid
            StoreOfflineRequest storeOfflineRequest
    );

    @Operation(summary = "重新构建")
    @PutMapping("/components/{storeId}/rebuild")
    CommonResult<Boolean> rebuild(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件Id", required = true)
            @PathVariable("storeId")
            String storeId
    );

    @Operation(summary = "返回上一步")
    @PutMapping("/components/{storeId}/step/back")
    CommonResult<Boolean> back(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "组件Id", required = true)
            @PathVariable("storeId")
            String storeId
    );
}